# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Platform Service."""

__version__ = "4.21.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .consume_user_entitlement import ConsumeUserEntitlement
from .disable_user_entitlement import DisableUserEntitlement
from .enable_user_entitlement import EnableUserEntitlement
from .exists_any_user_active__fca16a import ExistsAnyUserActiveEntitlement
from .exists_any_user_active__9d3175 import ExistsAnyUserActiveEntitlementByItemIds
from .get_entitlement import GetEntitlement
from .get_user_active_entitle_d52ca8 import GetUserActiveEntitlementsByItemIds
from .get_user_app_entitlemen_2375db import GetUserAppEntitlementByAppId
from .get_user_app_entitlemen_282639 import GetUserAppEntitlementOwnershipByAppId
from .get_user_entitlement import GetUserEntitlement
from .get_user_entitlement_by_8ab4a0 import GetUserEntitlementByItemId
from .get_user_entitlement_by_8ab4a0 import (
    EntitlementClazzEnum as GetUserEntitlementByItemIdEntitlementClazzEnum,
)
from .get_user_entitlement_by_sku import GetUserEntitlementBySku
from .get_user_entitlement_by_sku import (
    EntitlementClazzEnum as GetUserEntitlementBySkuEntitlementClazzEnum,
)
from .get_user_entitlement_histories import GetUserEntitlementHistories
from .get_user_entitlement_ow_ec2b70 import GetUserEntitlementOwnershipByItemId
from .get_user_entitlement_ow_ec2b70 import (
    EntitlementClazzEnum as GetUserEntitlementOwnershipByItemIdEntitlementClazzEnum,
)
from .get_user_entitlement_ow_5a8354 import GetUserEntitlementOwnershipByItemIds
from .get_user_entitlement_ow_dab0ca import GetUserEntitlementOwnershipBySku
from .get_user_entitlement_ow_dab0ca import (
    EntitlementClazzEnum as GetUserEntitlementOwnershipBySkuEntitlementClazzEnum,
)
from .grant_user_entitlement import GrantUserEntitlement
from .public_consume_user_ent_7254fa import PublicConsumeUserEntitlement
from .public_exists_any_my_ac_dbd2a5 import PublicExistsAnyMyActiveEntitlement
from .public_exists_any_user__3977e5 import PublicExistsAnyUserActiveEntitlement
from .public_get_entitlement__3fdfe7 import PublicGetEntitlementOwnershipToken
from .public_get_my_app_entit_4deb3f import PublicGetMyAppEntitlementOwnershipByAppId
from .public_get_my_entitleme_cb2911 import PublicGetMyEntitlementOwnershipByItemId
from .public_get_my_entitleme_cb2911 import (
    EntitlementClazzEnum as PublicGetMyEntitlementOwnershipByItemIdEntitlementClazzEnum,
)
from .public_get_my_entitleme_22c2fd import PublicGetMyEntitlementOwnershipBySku
from .public_get_my_entitleme_22c2fd import (
    EntitlementClazzEnum as PublicGetMyEntitlementOwnershipBySkuEntitlementClazzEnum,
)
from .public_get_user_app_ent_1e800f import PublicGetUserAppEntitlementByAppId
from .public_get_user_app_ent_53d109 import PublicGetUserAppEntitlementOwnershipByAppId
from .public_get_user_entitlement import PublicGetUserEntitlement
from .public_get_user_entitle_b1671e import PublicGetUserEntitlementByItemId
from .public_get_user_entitle_b1671e import (
    EntitlementClazzEnum as PublicGetUserEntitlementByItemIdEntitlementClazzEnum,
)
from .public_get_user_entitle_815992 import PublicGetUserEntitlementBySku
from .public_get_user_entitle_815992 import (
    EntitlementClazzEnum as PublicGetUserEntitlementBySkuEntitlementClazzEnum,
)
from .public_get_user_entitle_b313cf import PublicGetUserEntitlementOwnershipByItemId
from .public_get_user_entitle_b313cf import (
    EntitlementClazzEnum as PublicGetUserEntitlementOwnershipByItemIdEntitlementClazzEnum,
)
from .public_get_user_entitle_408425 import PublicGetUserEntitlementOwnershipByItemIds
from .public_get_user_entitle_ee3005 import PublicGetUserEntitlementOwnershipBySku
from .public_get_user_entitle_ee3005 import (
    EntitlementClazzEnum as PublicGetUserEntitlementOwnershipBySkuEntitlementClazzEnum,
)
from .public_query_user_entitlements import PublicQueryUserEntitlements
from .public_query_user_entitlements import (
    AppTypeEnum as PublicQueryUserEntitlementsAppTypeEnum,
    EntitlementClazzEnum as PublicQueryUserEntitlementsEntitlementClazzEnum,
)
from .public_query_user_entit_2398e5 import PublicQueryUserEntitlementsByAppType
from .public_query_user_entit_2398e5 import (
    AppTypeEnum as PublicQueryUserEntitlementsByAppTypeAppTypeEnum,
)
from .query_entitlements import QueryEntitlements
from .query_entitlements import (
    AppTypeEnum as QueryEntitlementsAppTypeEnum,
    EntitlementClazzEnum as QueryEntitlementsEntitlementClazzEnum,
)
from .query_user_entitlements import QueryUserEntitlements
from .query_user_entitlements import (
    AppTypeEnum as QueryUserEntitlementsAppTypeEnum,
    EntitlementClazzEnum as QueryUserEntitlementsEntitlementClazzEnum,
)
from .query_user_entitlements_22cea1 import QueryUserEntitlementsByAppType
from .query_user_entitlements_22cea1 import (
    AppTypeEnum as QueryUserEntitlementsByAppTypeAppTypeEnum,
)
from .revoke_user_entitlement import RevokeUserEntitlement
from .revoke_user_entitlements import RevokeUserEntitlements
from .update_user_entitlement import UpdateUserEntitlement
