# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Iam Service."""

__version__ = "5.25.4"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .add_role_managers import AddRoleManagers
from .add_role_members import AddRoleMembers
from .add_role_permission import AddRolePermission
from .admin_add_role_managers_v3 import AdminAddRoleManagersV3
from .admin_add_role_members_v3 import AdminAddRoleMembersV3
from .admin_add_role_permissions_v3 import AdminAddRolePermissionsV3
from .admin_add_role_permissions_v4 import AdminAddRolePermissionsV4
from .admin_assign_user_to_role_v4 import AdminAssignUserToRoleV4
from .admin_create_role_v3 import AdminCreateRoleV3
from .admin_create_role_v4 import AdminCreateRoleV4
from .admin_delete_role_permi_02ef33 import AdminDeleteRolePermissionV3
from .admin_delete_role_permi_c227c5 import AdminDeleteRolePermissionsV3
from .admin_delete_role_permi_22b25a import AdminDeleteRolePermissionsV4
from .admin_delete_role_v3 import AdminDeleteRoleV3
from .admin_delete_role_v4 import AdminDeleteRoleV4
from .admin_get_role_admin_status_v3 import AdminGetRoleAdminStatusV3
from .admin_get_role_managers_v3 import AdminGetRoleManagersV3
from .admin_get_role_members_v3 import AdminGetRoleMembersV3
from .admin_get_role_v3 import AdminGetRoleV3
from .admin_get_role_v4 import AdminGetRoleV4
from .admin_get_roles_v3 import AdminGetRolesV3
from .admin_get_roles_v4 import AdminGetRolesV4
from .admin_list_assigned_users_v4 import AdminListAssignedUsersV4
from .admin_remove_role_admin_v3 import AdminRemoveRoleAdminV3
from .admin_remove_role_managers_v3 import AdminRemoveRoleManagersV3
from .admin_remove_role_members_v3 import AdminRemoveRoleMembersV3
from .admin_revoke_user_from_role_v4 import AdminRevokeUserFromRoleV4
from .admin_update_admin_role_5be907 import AdminUpdateAdminRoleStatusV3
from .admin_update_role_permi_728d52 import AdminUpdateRolePermissionsV3
from .admin_update_role_permi_e17189 import AdminUpdateRolePermissionsV4
from .admin_update_role_v3 import AdminUpdateRoleV3
from .admin_update_role_v4 import AdminUpdateRoleV4
from .create_role import CreateRole
from .delete_role import DeleteRole
from .delete_role_permission import DeleteRolePermission
from .get_role import GetRole
from .get_role_admin_status import GetRoleAdminStatus
from .get_role_managers import GetRoleManagers
from .get_role_members import GetRoleMembers
from .get_roles import GetRoles
from .public_get_role_v3 import PublicGetRoleV3
from .public_get_roles_v3 import PublicGetRolesV3
from .remove_role_admin import RemoveRoleAdmin
from .remove_role_managers import RemoveRoleManagers
from .remove_role_members import RemoveRoleMembers
from .set_role_as_admin import SetRoleAsAdmin
from .update_role import UpdateRole
from .update_role_permissions import UpdateRolePermissions
