# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Social Service."""

__version__ = "1.32.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .get_slot_data import GetSlotData
from .get_user_namespace_slots import GetUserNamespaceSlots
from .public_create_user_name_1e93c7 import PublicCreateUserNamespaceSlot
from .public_delete_user_name_9ed44a import PublicDeleteUserNamespaceSlot
from .public_get_slot_data import PublicGetSlotData
from .public_get_user_namespa_083368 import PublicGetUserNamespaceSlots
from .public_update_user_name_d493ff import PublicUpdateUserNamespaceSlot
from .public_update_user_name_fc60e7 import PublicUpdateUserNamespaceSlotMetadata
