# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Match Service V2."""

__version__ = "2.0.1"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from ._backfill import accept_backfill
from ._backfill import accept_backfill_async
from ._backfill import create_backfill
from ._backfill import create_backfill_async
from ._backfill import reject_backfill
from ._backfill import reject_backfill_async

from ._match_functions import create_match_function
from ._match_functions import create_match_function_async
from ._match_functions import delete_match_function
from ._match_functions import delete_match_function_async
from ._match_functions import match_function_list
from ._match_functions import match_function_list_async

from ._match_pools import create_match_pool
from ._match_pools import create_match_pool_async
from ._match_pools import delete_match_pool
from ._match_pools import delete_match_pool_async
from ._match_pools import match_pool_details
from ._match_pools import match_pool_details_async
from ._match_pools import match_pool_list
from ._match_pools import match_pool_list_async
from ._match_pools import update_match_pool
from ._match_pools import update_match_pool_async

from ._match_tickets import create_match_ticket
from ._match_tickets import create_match_ticket_async
from ._match_tickets import delete_match_ticket
from ._match_tickets import delete_match_ticket_async
from ._match_tickets import match_ticket_details
from ._match_tickets import match_ticket_details_async

from ._operations import get_healthcheck_info
from ._operations import get_healthcheck_info_async
from ._operations import get_healthcheck_info_v1
from ._operations import get_healthcheck_info_v1_async
from ._operations import version_check_handler
from ._operations import version_check_handler_async

from ._rule_sets import create_rule_set
from ._rule_sets import create_rule_set_async
from ._rule_sets import delete_rule_set
from ._rule_sets import delete_rule_set_async
from ._rule_sets import rule_set_details
from ._rule_sets import rule_set_details_async
from ._rule_sets import rule_set_list
from ._rule_sets import rule_set_list_async
from ._rule_sets import update_rule_set
from ._rule_sets import update_rule_set_async
